#[non_exhaustive]pub struct ApplyResult {
pub ok: bool,
pub modified_files: Vec<PathBuf>,
pub diagnostics: Vec<Diagnostic>,
pub reload_hint: ReloadHint,
}Expand description
What happened when an EditCommand was applied.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ok: boolWhether the edit succeeded.
modified_files: Vec<PathBuf>Files whose in-memory model was changed. Use this to drive the GUI’s “unsaved changes” indicator.
diagnostics: Vec<Diagnostic>Problems found during apply. Non-empty when ok is false.
reload_hint: ReloadHintWhether the running server would need a reload / restart to see this change. Informational — the server control layer decides what to do with the hint.